# Application of Pace Layering in Assessments
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/application-of-pace-layering-in-assessments#overview)
  * [Focusing on Specific Capabilities](https://help.sap.com/docs/leanix/ea/application-of-pace-layering-in-assessments#focusing-on-specific-capabilities)
  * [Integrating TIME Classification with Pace Layering](https://help.sap.com/docs/leanix/ea/application-of-pace-layering-in-assessments#integrating-time-classification-with-pace-layering)
  * [Creating and Implementing a Future-State/To-Be-State Plan](https://help.sap.com/docs/leanix/ea/application-of-pace-layering-in-assessments#creating-and-implementing-a-future-state/to-be-state-plan)


Learn how to use pace layering to guide assessments.
